@@ -6,6 +6,10 @@
 #ifndef _ALMEMSYS_H_
   #define _ALMEMSYS_H_
 
+  #ifndef _STDIO_H_
+    #include<stdio.h>
+  #endif
+
   #ifndef _TIME_H_
     #include<time.h>
   #endif
