@@ -66,7 +66,15 @@ ret = swap_mem(taro, '2', '1', strlen(taro));
 printf("SWAP_MEM DATA= %s RET=%d\n", taro, ret);
 ret = unlinkdir("/home/masashi/dirtest/");
 printf("UNLINKDIR PATH= %s RET=%d\n", "/home/masashi/dirtest/", ret);
-
+printf("char_wday(1) = %s\n", char_wday(1));
+printf("char_mon(1) = %s\n", char_wday(1));
+printf("utime_getr(0, 'y') = %d\n", utime_getr(0, 'y'));
+printf("utime_getr(0, 'm') = %d\n", utime_getr(0, 'm'));
+printf("utime_getr(0, 'd') = %d\n", utime_getr(0, 'd'));
+printf("cutime_getr('y') = %d\n", ctime_getr('y'));
+printf("cutime_getr('m') = %d\n", ctime_getr('m'));
+printf("cutime_getr('d') = %d\n", ctime_getr('d'));
+printf("time_minus(0, 1, 'h') = %d\n", time_minus(0, 1, 'h'));
 
 return 0;
 }
