@@ -374,7 +374,7 @@ if($num > 0){
       echo "<td $kcal2><font size=1>*</font></td>";
       echo "<td $kcal2><font size=1>*</font></td>";
       echo "<td $kcal2><font size=1>*</font></td>";
-      echo "<td $kcal2><font size=1>*</font></td>";
+      echo "<td $kcal2><font size=1>Ʊƻĥ꡼</font></td>";
       echo "<td $kcal2><font size=1>*</font></td>";
       echo "<td $kcal2><font size=1>*</font></td>";
       echo "<td $kcal2><font size=1>*</font></td>";
@@ -418,23 +418,47 @@ if($num > 0){
          $pcol = "bgcolor=red";
          $prcol = "bgcolor=red";
          } 
-      if($PRINO == 2){
+      else if($PRINO == 2){
          $pcol = "bgcolor=magenta";
          $prcol = "bgcolor=magenta";
          } 
-      if($PRINO == 3){
+      else if($PRINO == 3){
          $pcol = "bgcolor=green";
          $prcol = "bgcolor=green";
          }
-      if($PRINO == 4){
+      else if($PRINO == 4){
          $pcol = "bgcolor=orengi";
          $prcol = "bgcolor=orengi";
          }
-
-      if($PRINO > 4){
-         $pcol = "bgcolor=white";
-         $prcol = "bgcolor=white";
+      else if($PRINO == 5){
+         $pcol = "bgcolor='#ffff99'";
+         $prcol = "bgcolor='#ffff99'";
          }
+      else if($PRINO == 6){
+         $pcol = "bgcolor='#ffff99'";
+         $prcol = "bgcolor='#ffff99'";
+         }
+      else if($PRINO == 11){
+         $pcol = "bgcolor='#cc0099'";
+         $prcol = "bgcolor='#cc0099'";
+         }
+      else if($PRINO == 12){
+         $pcol = "bgcolor='#9900ff'";
+         $prcol = "bgcolor='#9900ff'";
+         }
+      else if($PRINO == 13){
+         $pcol = "bgcolor='#99cc00'";
+         $prcol = "bgcolor='#99cc00'";
+         }
+      else{
+         $pcol = "bgcolor=cyan";
+         $prcol = "bgcolor=cyan";
+         }
+
+
+
+
+
  
       if(0 == strcmp("on", $csv_ch)){
          print("$MONITOR,$SIGN,$PROTO,$COM,$CIP,$PORT,$WTIME,$PINFO,$PRINO,$FREE1,$FREE2,$UNO,$FREE4,\n");
@@ -449,7 +473,7 @@ if($num > 0){
          echo "<td $ncol2>$SIGN</td>";
          echo "<td $ncol1>$PROTO</td>";
          echo "<td $ncol2>$COM</td>";
-         echo "<td $ncol1>$CIP</td>";
+         echo "<td $ncol1><a target=edit href='tree2.php?CIP=$CIP'>$CIP</a></td>";
          echo "<td $ncol2>$PORT</td>";
          echo "<td $ncol1>$WTIME</td>";
          echo "<td $ncol2>$PINFO</td>";
@@ -507,7 +531,10 @@ if($num > 0){
         echo "<option value=2>(2)";
         echo "<option value=3>᡼Фʤ(3)";
         echo "<option value=4>ƥȥ⡼(4)";
-        echo "<option value=5>⡼(>5)";
+        echo "<option value=5>⡼(5)";
+        echo "<option value=11>ƻ⡼(11)";
+        echo "<option value=12>ƻ⡼(12)";
+        echo "<option value=13>ƻ⡼(13)";
         echo "</select>";
       echo "</td>";
 
