@@ -484,18 +484,40 @@ else {
       if($PRINO <= 1){
          $pcol = "bgcolor=red";
          } 
-      if($PRINO == 2){
+      else if($PRINO == 2){
          $pcol = "bgcolor=magenta";
          } 
-      if($PRINO == 3){
+      else if($PRINO == 3){
          $pcol = "bgcolor=green";
          }
-      if($PRINO == 4){
+      else if($PRINO == 4){
          $pcol = "bgcolor=orengi";
          }
-      if($PRINO >= 5){
-         $pcol = "bgcolor=white";
+      else if($PRINO == 5){
+         $pcol = "bgcolor='#ffff99'";
          }
+      else if($PRINO == 6){
+         $pcol = "bgcolor='#ffff99'";
+         }
+      else if($PRINO == 11){
+         $pcol = "bgcolor='#cc0099'";
+         }
+      else if($PRINO == 12){
+         $pcol = "bgcolor='#9900ff'";
+         }
+      else if($PRINO == 13){
+         $pcol = "bgcolor='#99cc00'";
+         }
+      else{
+         $pcol = "bgcolor=cyan";
+         }
+
+
+
+
+
+
+
 
          echo "<td $pcol><a target=top href=$my_url/monitor_edit.php?UNO=$FREE3&STATUS=UPDATE>$MO/$DA $HA:$MI:$SE</a></td>";
          echo "<td $ncol2>$CINFO</td>";
