@@ -7,7 +7,11 @@
 
   #include"config.h"
 
-  #define CL_VAR "sitar_proxy-1.1.13"
+  #ifndef _VERSION_H_
+     #include "version.h"
+  #endif
+
+  #define CL_VAR "sitar_proxy-"VERSION
 
   #define BUF_LEN 1024
   #define BUF_DEFLEN 128
@@ -17,7 +21,7 @@
   #define INT_VAL 30
 
   /* debug option */
-//  #define PROXY_BUG
+  #define PROXY_BUG
 
   struct buf_data{
      char ** getdata;
