@@ -1,14 +1,9 @@
-// mallocset.c
-// $Id: mallocset.c,v 1.3 2007/11/13 11:45:17 sendan Exp $
-// masashi shimakura
 
 #include<stdio.h>
 #include<netinet/in.h>
 #include<stdlib.h>
-#include<pthread.h>
 
 #include"sitar.h"
-#include"sitar_scan.h"
 #include<almemsys/almemsys.h>
 
 
