@@ -1,17 +1,11 @@
-// opt.c
-// $Id: opt.c,v 1.2 2007/11/01 05:57:06 sendan Exp $
-// masashi shimakura
-
 
 #include<stdio.h>
 #include<netinet/in.h>
 #include<string.h>
 #include<stdlib.h>
 #include<unistd.h>
-#include<pthread.h>
 
 #include"sitar.h"
-#include<almemsys/almemsys.h>
 
 extern global_data_t gd;
 
