@@ -37,6 +37,9 @@ int scan_port(struct scan_buf *);
 /* --- scan_snmp.c --- */
 int scan_snmp(struct scan_buf *);
 
+/* --- scan_comand.c --- */
+int scan_comand(private_data_t *);
+
 /* --- filestat.c --- */
 char * stat_check(char *, char *, int, int *);
 
@@ -47,4 +50,8 @@ int floop(int, int, int, int, int,    int, int, int, int, int);
 /* --- time_format.c --- */
 int time_format(char *, int *, int *, int *, int *, int *);
 
+/* --- swap_char.c --- */
+int swap_char(char *);
+
+
 
