@@ -1,23 +1,20 @@
-// scan_icmp.c
-// $Id: scan_icmp.c,v 1.1.1.1 2007/09/19 05:49:54 sendan Exp $
-// masashi shimakura
 
 #include<stdio.h>
-#include<string.h>
+//#include<string.h>
 #include<unistd.h>
-#include<sys/socket.h>
+//#include<sys/socket.h>
 #include<sys/time.h>
-#include<netinet/in_systm.h>
-#include<netinet/in.h>
-#include<netinet/ip.h>
+//#include<netinet/in_systm.h>
+//#include<netinet/in.h>
+//#include<netinet/ip.h>
 #include<netinet/ip_icmp.h>
-#include<arpa/inet.h>
+//#include<arpa/inet.h>
 
-#include<sys/stat.h> 
+//#include<sys/stat.h> 
 #include<sys/un.h>
 
 #include"sitar_scan.h"
-#include"sitar_com.h"
+//#include"sitar_com.h"
 #include<almemsys/almemsys.h>
 #include"jpreturn.h"
 
