@@ -1,12 +1,8 @@
-// scan_snmp.c
-// $Id: scan_snmp.c,v 1.5 2007/11/01 05:57:06 sendan Exp $
-// masashi shimakura
 
 #include<stdio.h>
 #include<netinet/in.h>
 #include<string.h>
 #include<stdlib.h>
-#include<pthread.h>
 
 #include"sitar.h"
 #include"sitar_scan.h"
@@ -65,7 +61,7 @@ if(0 == memcmp(oid, "cal", 3)){
             calchar = da[0];
             backdata = safe_sprintf(backdata, BUF_MAX,"%s (%c)\n", SNMP_3, calchar);
             #ifdef SNMP_DEBUG
-            printf("+-*/Da = %c\n", calchar);
+            printf("SNMP_DEBUG: cal_oid(1): +-*/Da = %c\n", calchar);
             #endif
             }
          else{
@@ -74,7 +70,7 @@ if(0 == memcmp(oid, "cal", 3)){
                kaz = strtol(da, (char **)NULL, 10);
                backdata = safe_sprintf(backdata, BUF_MAX,"%s (%d)\n", SNMP_22, kaz);
                #ifdef SNMP_DEBUG
-               printf("1234Da = %d\n", kaz);
+               printf("SNMP_DEBUG: cal_oid(2): 1234Da = %d\n", kaz);
                #endif
                * ret = cal4(* ret, kaz, calchar);
                kaz = 0;
@@ -83,7 +79,7 @@ if(0 == memcmp(oid, "cal", 3)){
                if(0 != memcmp(da, "cal", 3)){
                   backdata = snmp_test(backdata, port, host, da, stat, 2, chk, timeout);
                   #ifdef SNMP_DEBUG
-                  printf("M->OID Da = %s %d %s %d\n", da, *chk, backdata, *stat);
+                  printf("SNMP_DEBUG: cal_oid(3): M->OID Da = %s %d %s %d\n", da, *chk, backdata, *stat);
                   #endif
                   if(* stat >= 0 && * chk < 4){
                      kaz = strtol(backdata, (char **)NULL, 10);
@@ -96,14 +92,15 @@ if(0 == memcmp(oid, "cal", 3)){
                      * stat = -1;
                      * ret = 0;
                      #ifdef SNMP_DEBUG
-                     backdata = safe_sprintf(backdata, BUF_MAX, "%s OID<%s>\n", SNMP_5, da);
+                     printf("SNMP_DEBUG: cal_oid(4): %s OID<%s>\n", SNMP_5, da);
                      #endif
+                     backdata = safe_sprintf(backdata, BUF_MAX, "%s OID<%s>\n", SNMP_5, da);
                      return backdata;
                      }
                   }
                else{
                   #ifdef SNMP_DEBUG
-                  fprintf(stderr, "head string is 'cal' Da = %s\n", da);
+                  printf("SNMP_DEBUG: cal_oid(5): head string is 'cal' Da = %s\n", da);
                   #endif
                   }
               }
@@ -111,7 +108,7 @@ if(0 == memcmp(oid, "cal", 3)){
             }
          }
       else{
-         fprintf(stderr,"Da size = 0\n");
+         fprintf(stderr,"cal_oid(): Da size = 0\n");
          }      
       free(da);
       }
@@ -128,7 +125,7 @@ else{
    else{
       backdata = snmp_test(backdata, port, host, oid, stat, 2, chk, timeout);
       #ifdef SNMP_DEBUG
-      printf("S->OID Da = %s %d %s\n", oid, * stat, backdata);
+      printf("SNMP_DEBUG: cal_oid(6): S->OID Da = %s %d %s\n", oid, * stat, backdata);
       #endif
       if(* stat >= 0 && * chk < 4){
          kaz = strtol(backdata, (char **)NULL, 10);
@@ -141,8 +138,9 @@ else{
          * stat = -1;
          * ret = 0;
          #ifdef SNMP_DEBUG
-         backdata = safe_sprintf(backdata, BUF_MAX, "%s OID<%s> stat<%d>\n", SNMP_5, oid, * stat);
+         printf("SNMP_DEBUG: cal_oid(7): %s OID<%s> stat<%d>\n", SNMP_5, oid, * stat);
          #endif
+         backdata = safe_sprintf(backdata, BUF_MAX, "%s OID<%s> stat<%d>\n", SNMP_5, oid, * stat);
          return backdata;
          }
       }
@@ -204,7 +202,7 @@ else if(chA == '/'){
    return ret;
    }
 else{
-   fprintf(stderr,"(%d) %s\n", ret, SNMP_24);
+   fprintf(stderr,"cal4(): (%d) %s\n", ret, SNMP_24);
    return ret;
    }
 
@@ -217,25 +215,47 @@ return 0;
 /* ------ SCAN PORT --------- */
 int scan_snmp(struct scan_buf *pd)
 {
-int ret, hi, inret, chk;
+int ret, hi, inret, chk, plai;
 ret = 0;
 hi = 0;
 inret = 0;
 chk = 0;
+plai = 0;
 
 char * chhi = (char *)calloc(IP_LEN, sizeof(char));
 char * chho = (char *)calloc(IP_LEN, sizeof(char));
 char * backdata = (char *)calloc(IP_LEN, sizeof(char));
 
+if(0 == ch_int2(pd->ch_plai)){
+   plai = strtol(pd->ch_plai, (char **)NULL, 10);
+   }
+else{
+   plai = 3;
+   }
+
 // 閾値がNOTの場合、戻り値は編集なしで全てそのまま返す。
 if(0 == memcmp(pd->ch_prot, "NOT", 3) || 0 == memcmp(pd->ch_port, "NON", 3)){
    pd->ch_info = cal_oid(pd->ch_com, pd->ch_info, &ret, &inret, pd->ch_port, pd->ch_host, &chk, pd->timeout);
    backdata = safe_sprintf(backdata, BUF_MAX,"(%s) %s\n", pd->ch_info, SNMP_23);
    pd->ch_info = safe_memcpy(pd->ch_info, backdata, BUF_MAX);
-// pd->ch_info = safe_strncat(pd->ch_info, SNMP_23, BUF_MAX);
-// pd->ch_info = safe_strncat(pd->ch_info, "\n", BUF_MAX);
    #ifdef SNMP_DEBUG
-   printf("===== ch_info = <%s>: inret = <%d>: stat = <%d>:======\n", pd->ch_info, inret, ret);
+   printf("SNMP_DEBUG: scan_snmp(): ch_info = <%s>: inret = <%d>: stat = <%d>\n", pd->ch_info, inret, ret);
+   #endif
+   ret = -1;
+   if(0 == (int)strlen(pd->ch_info)){
+      ret = -1;
+      pd->ch_info=safe_memcpy(pd->ch_info,"SNMP Information is a no bur error.\n",BUF_MAX);
+      }
+   }
+
+
+// 閾値がLOGの場合、戻りを数字に戻さず、そのまま返す。
+else if(0 == memcmp(pd->ch_prot, "LOG", 3) || 0 == memcmp(pd->ch_port, "log", 3)){
+
+   pd->ch_info = snmp_test(pd->ch_info, pd->ch_port, pd->ch_host, pd->ch_com, &ret, 0, &chk, pd->timeout);
+
+   #ifdef SNMP_DEBUG
+   printf("SNMP_DEBUG: scan_snmp(): ch_info = <%s>: inret = <%d>: stat = <%d>\n", pd->ch_info, inret, ret);
    #endif
    ret = -1;
    if(0 == (int)strlen(pd->ch_info)){
@@ -247,12 +267,13 @@ if(0 == memcmp(pd->ch_prot, "NOT", 3) || 0 == memcmp(pd->ch_port, "NON", 3)){
 
 // 閾値の先頭が−の場合
 else if(pd->ch_prot[0] == '-' && 1 < (int)strlen(pd->ch_prot)){
+
    chhi = safe_memcpy(chhi, pd->ch_prot + 1, BUF_MAX);
    if(-1 != ch_int(chhi)){
       if((hi = strtol(chhi, (char **)NULL, 10)) >= 0){
          pd->ch_info = cal_oid(pd->ch_com, pd->ch_info, &ret, &inret, pd->ch_port, pd->ch_host, &chk, pd->timeout);
          #ifdef SNMP_DEBUG
-         printf("%s\n%s", pd->ch_info, pd->ch_free1);
+         printf("SNMP_DEBUG: scan_snmp(): %s\n%s", pd->ch_info, pd->ch_free1);
          #endif
          if(4 == chk){
             ret = -1;
@@ -268,11 +289,21 @@ else if(pd->ch_prot[0] == '-' && 1 < (int)strlen(pd->ch_prot)){
          else{
             if(hi > inret){
                ret = -1;
-               pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"%d > %d %s\n", hi, inret, SNMP_11);
+               if(0 < plai && 5 > plai){
+                  pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"1 %d > %d %s\n", hi, inret, SNMP_11);
+                  }
+               else{
+                  pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"%d\n", inret);
+                  }
                }
             else{
                ret = 0;
-               pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"%d < %d %s\n", hi, inret, SNMP_12);
+               if(0 < plai && 5 > plai){
+                  pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"3 %d < %d %s\n", hi, inret, SNMP_12);
+                  }
+               else{
+                  pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"%d\n", inret);
+                  }
                }
             }
          }
@@ -295,7 +326,7 @@ else if(pd->ch_prot[0] == '+' && 1 < (int)strlen(pd->ch_prot)){
       if((hi = strtol(chhi, (char **)NULL, 10)) >= 0){
          pd->ch_info = cal_oid(pd->ch_com, pd->ch_info, &ret, &inret, pd->ch_port, pd->ch_host, &chk, pd->timeout);
          #ifdef SNMP_DEBUG
-         printf("%s\n%s", pd->ch_info, pd->ch_free1);
+         printf("SNMP_DEBUG: scan_snmp(): %s\n%s", pd->ch_info, pd->ch_free1);
          #endif
          if(4 == chk){
             ret = -1;
@@ -311,11 +342,21 @@ else if(pd->ch_prot[0] == '+' && 1 < (int)strlen(pd->ch_prot)){
          else{
             if(hi < inret){
                ret = -1;
-               pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"%d < %d %s\n", hi, inret, SNMP_11);
+               if(0 < plai && 5 > plai){
+                  pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"%d < %d %s\n", hi, inret, SNMP_11);
+                  }
+               else{
+                  pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"%d\n", inret);
+                  }
                }
             else{
                ret = 0;
-               pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"%d > %d %s\n", hi, inret, SNMP_12);
+               if(0 < plai && 5 > plai){
+                  pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"%d > %d %s\n", hi, inret, SNMP_12);
+                  }
+               else{
+                  pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,"%d\n", inret);
+                  }
                }
             }
          }
@@ -336,7 +377,7 @@ else if(pd->ch_prot[0] == '!' && 1 < (int)strlen(pd->ch_prot)){
    chhi = safe_memcpy(chhi, pd->ch_prot + 1, BUF_MAX);
    pd->ch_info = snmp_test(pd->ch_info, pd->ch_port, pd->ch_host, pd->ch_com, &ret, 1, &chk, pd->timeout);
    #ifdef SNMP_DEBUG
-   printf("%s\n%s\n%s\n", pd->ch_info, pd->ch_free1, chhi);
+   printf("SNMP_DEBUG: scan_snmp(): %s\n%s\n%s\n", pd->ch_info, pd->ch_free1, chhi);
    #endif
    if(0 > ret){
       if(0 == (int)strlen(pd->ch_info)){
@@ -346,16 +387,25 @@ else if(pd->ch_prot[0] == '!' && 1 < (int)strlen(pd->ch_prot)){
       }
    else{
       chho = safe_memcpy(chho, pd->ch_info, BUF_MAX);
-//    if(0 != memcmp(chhi, chho, (int)strlen(chho))){
       if(0 != self_memcmp(chhi, chho)){
          ret = -1;
-         pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,
-            "%s\n                   1(%s)\n                   2(%s)\n", SNMP_19, chhi, chho);
+         if(0 < plai && 5 > plai){
+            pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,
+               "%s\n                   1(%s)\n                   2(%s)\n", SNMP_19, chhi, chho);
+            }
+         else{
+            pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX, "%s\n", chho);
+            }
          }
       else{
          ret = 0;
-         pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,
-            "%s\n                   1(%s)\n                   2(%s)\n", SNMP_20, chhi, chho);
+         if(0 < plai && 5 > plai){
+            pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,
+               "%s\n                   1(%s)\n                   2(%s)\n", SNMP_20, chhi, chho);
+            }
+         else{
+            pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX, "%s\n", chho);
+            }
          }
       }
    }
@@ -366,7 +416,7 @@ else if(pd->ch_prot[0] == '=' && 1 < (int)strlen(pd->ch_prot)){
    chhi = safe_memcpy(chhi, pd->ch_prot + 1, BUF_MAX);
    pd->ch_info = snmp_test(pd->ch_info, pd->ch_port, pd->ch_host, pd->ch_com, &ret, 1, &chk, pd->timeout);
    #ifdef SNMP_DEBUG
-   printf("%s\n%s\n%s\n", pd->ch_info, pd->ch_free1, chhi);
+   printf("SNMP_DEBUG: scan_snmp(): %s\n%s\n%s\n", pd->ch_info, pd->ch_free1, chhi);
    #endif
    if(0 > ret){
       if(0 == (int)strlen(pd->ch_info)){
@@ -376,16 +426,25 @@ else if(pd->ch_prot[0] == '=' && 1 < (int)strlen(pd->ch_prot)){
       }
    else{
       chho = safe_memcpy(chho, pd->ch_info, BUF_MAX);
-//    if(0 == memcmp(chhi, chho, (int)strlen(chho))){
       if(0 != self_memcmp(chhi, chho)){
          ret = 0;
-         pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,
-            "%s\n                   1(%s)\n                   2(%s)\n", SNMP_19, chhi, chho);
+         if(0 < plai && 5 > plai){
+            pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,
+               "%s\n                   1(%s)\n                   2(%s)\n", SNMP_19, chhi, chho);
+            }
+         else{
+            pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX, "%s\n", chho);
+            }
          }
       else{
          ret = -1;
-         pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,
-            "%s\n                   1(%s)\n                   2(%s)\n", SNMP_20, chhi, chho);
+         if(0 < plai && 5 > plai){
+            pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,
+               "%s\n                   1(%s)\n                   2(%s)\n", SNMP_20, chhi, chho);
+            }
+         else{
+            pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX, "%s\n", chho);
+            }
          }
       }
    }
@@ -396,11 +455,9 @@ else {
    pd->ch_info = cal_oid(pd->ch_com, pd->ch_info, &ret, &inret, pd->ch_port, pd->ch_host, &chk, pd->timeout);
    backdata = safe_sprintf(backdata, BUF_MAX,"(%s) %s\n", pd->ch_info, SNMP_13);
    pd->ch_info = safe_memcpy(pd->ch_info, backdata, BUF_MAX);
-// pd->ch_info = safe_strncat(pd->ch_info, SNMP_13, BUF_MAX);
-// pd->ch_info = safe_strncat(pd->ch_info, "\n", BUF_MAX);
    #ifdef SNMP_DEBUG
-   printf("%s\n%s", pd->ch_info, pd->ch_free1);
-   printf("===== backdata = <%s>: inret = <%d>: stat = <%d>:======\n", backdata, inret, ret);
+   printf("SNMP_DEBUG: scan_snmp(): %s\n%s", pd->ch_info, pd->ch_free1);
+   printf("SNMP_DEBUG: scan_snmp(): backdata = <%s>: inret = <%d>: stat = <%d>\n", backdata, inret, ret);
    #endif
    ret = -1;
    if(0 == (int)strlen(pd->ch_info)){
@@ -410,7 +467,46 @@ else {
    }
 
 
-// 監視の正逆の判断
+
+// テストとログモードの処理
+if(0 == self_memcmp(pd->ch_plai, "4")){
+   #ifdef SNMP_DEBUG
+   printf("SNMP_DEBUG: scan_snmp(): snmp chack plai=%d check_stat=%d\n", pd->ch_plai, pd->check_stat);
+   #endif
+   ret = -1;
+   }
+else if(0 == self_memcmp(pd->ch_plai, "11")){
+   #ifdef SNMP_DEBUG
+   printf("SNMP_DEBUG: scan_snmp(): snmp chack plai=%d check_stat=%d\n", pd->ch_plai, pd->check_stat);
+   #endif
+   if(ret == -1){
+      pd->ch_plai = safe_memcpy(pd->ch_plai, "1", BUF_MAX);
+      }
+   ret = -1;
+   }
+else if(0 == self_memcmp(pd->ch_plai, "12")){
+   #ifdef SNMP_DEBUG
+   printf("SNMP_DEBUG: scan_snmp(): snmp chack plai=%d check_stat=%d\n", pd->ch_plai, pd->check_stat);
+   #endif
+   if(ret == -1){
+      pd->ch_plai = safe_memcpy(pd->ch_plai, "2", BUF_MAX);
+      }
+   ret = -1;
+   }
+else if(0 == self_memcmp(pd->ch_plai, "13")){
+   #ifdef SNMP_DEBUG
+   printf("SNMP_DEBUG: scan_snmp(): snmp chack plai=%d check_stat=%d\n", pd->ch_plai, pd->check_stat);
+   #endif
+   if(ret == -1){
+      pd->ch_plai = safe_memcpy(pd->ch_plai, "3", BUF_MAX);
+      }
+   ret = -1;
+   }
+
+
+
+// check_statの設定 正か逆かで反転する。
+// 監視の正逆の判断 check_stat == 1 はエラー 0は正常
 if(ret < 0){
    if(pd->ch_stat[0] == '0'){
       pd->check_stat = 1;
@@ -430,14 +526,6 @@ if(ret >= 0){
       }
    }
 
-// テストモード（４）の場合の処理
-if(0 == memcmp(pd->ch_plai, "4", 1)){
-   #ifdef SNMP_DEBUG
-   printf("snmp chack out = \n");
-   #endif
-   pd->check_stat = 1;
-   ret = -1;
-   }
 
 /* */
 free(chhi);
@@ -445,7 +533,7 @@ free(chho);
 free(backdata);
 
 #ifdef SNMP_DEBUG
-printf("==DATA=== ch_info = <%s>: inret = <%d>: stat = <%d>:======\n", pd->ch_info, inret, ret);
+printf("SNMP_DEBUG: scan_snmp(): ch_info = <%s>: inret = <%d>: stat = <%d>\n", pd->ch_info, inret, ret);
 #endif
 
 return(ret);
