@@ -6,27 +6,12 @@
 /* EUC-JP */
 
 #include<stdio.h>
-#include<stdlib.h>
-#include<string.h>
-#include<netdb.h>
 #include<unistd.h>
 #include<time.h>
-#include<sys/types.h>
-#include<sys/socket.h>
-#include<netinet/in_systm.h>
-#include<netinet/in.h>
-#include<netinet/ip.h>
-#include<netinet/ip_icmp.h>
-#include<arpa/inet.h>
-#include<fcntl.h>
-
-#include<sys/stat.h>
 #include<sys/un.h>
 #include<sys/time.h>
-#include<errno.h>
 
 #include"sitar_scan.h"
-#include"sitar_com.h"
 #include<almemsys/almemsys.h>
 #include"jpreturn.h"
 
