@@ -1,22 +1,10 @@
-// scan_udpport.c
-// $Id: scan_udpport.c,v 1.1.1.1 2007/09/19 05:49:54 sendan Exp $
-// masashi shimakura
-
 
 #include<stdio.h>
-#include<string.h>
 #include<netdb.h>
 #include<unistd.h>
-#include<sys/socket.h>
-#include<netinet/in_systm.h>
-#include<netinet/in.h>
-#include<netinet/ip.h>
 #include<netinet/ip_icmp.h>
-#include<sys/stat.h>
-#include<arpa/inet.h>
 
 #include"sitar_scan.h"
-#include"sitar_com.h"
 #include<almemsys/almemsys.h>
 #include"jpreturn.h"
 
