@@ -1,20 +1,10 @@
-// scan_urlport.c
-// $Id: scan_urlport.c,v 1.1.1.1 2007/09/19 05:49:54 sendan Exp $
-// masashi shimakura
 
 #include<stdio.h>
 #include<stdlib.h>
 #include<string.h>
-#include<netdb.h>
 #include<unistd.h>
-#include<sys/socket.h>
-#include<netinet/in_systm.h>
-#include<netinet/in.h>
-#include<netinet/ip.h>
-#include<arpa/inet.h>
 #include<fcntl.h>
 
-#include<sys/stat.h>
 #include<errno.h>
 
 #include"sitar_scan.h"
@@ -22,7 +12,6 @@
 #include<almemsys/almemsys.h>
 #include"jpreturn.h"
 
-// struct buf_data bd;
 
 
 /* 1-> port No' 2-> Ipsddr 3-> return data,, return status code 0=open or=close
