@@ -1,25 +1,17 @@
-// sitar.c
-// $Id: sitar.c,v 1.8 2007/11/14 04:08:53 sendan Exp $
-// masashi shimakura
 
 #include<stdio.h>
-#include<sys/types.h>
 #include<unistd.h>
 #include<sys/wait.h>
-#include<sys/stat.h>
 #include<netinet/in.h>
-#include<fcntl.h>
 #include<string.h>
 #include<stdlib.h>
-#include<signal.h>
 #include<pthread.h>
-#include<errno.h>
 
 #include"sitar.h"
 #include"sitar_com.h"
-#include"almemsys.h"
-#include "jpreturn.h"
-#include "file_comp.h"
+#include<almemsys/almemsys.h>
+#include"jpreturn.h"
+#include<file_comp/file_comp.h>
 
 global_data_t gd;
 swap_array_t sa;
@@ -41,9 +33,9 @@ int start_neg(void);
 int life_put(void);
 int life_pthread(void);
 int sitar_scan(void);
-int swap_char(char *);
+// int swap_char(char *);
 int my_chmem(char *, char *);
-int scan_comand(private_data_t *);
+// int scan_comand(private_data_t *);
 char * check_strtol(char *);
 void * scan_block(int);
 
@@ -285,13 +277,13 @@ for(;;){
             for(fdcountstat = 0;fdcountstat == 0;){
                for(fdcount = 0; fdcount < gd.td.tcount; fdcount++){
                   #ifdef THREAD_BUG
-                  printf("THREAD_BUG: sitar_scan(END block): fdcount<%ld>fdstat<%d>\n",
-                    fdcount, gd.td.fdstat[fdcount]);
+                  printf("THREAD_BUG: sitar_scan(END block 1): fdcount<%ld>fdstat<%d>\n",
+                  fdcount, gd.td.fdstat[fdcount]);
                   #endif
                   if(gd.td.fdstat[fdcount] != 1){
                      gd.td.fdstat[fdcount] = 1;
                      #ifdef FREE_BUG
-                     printf("FREE: sitar_scan(END block): safree(%ld) fdcount\n", fdcount);
+                     printf("FREE: sitar_scan(END block 2): safree(%ld) fdcount\n", fdcount);
                      #endif
                      safree(fdcount);
                      sacalloc(fdcount);
@@ -304,7 +296,7 @@ for(;;){
                      sa.swap_data[fdcount][count] = safe_memcpy(
                          sa.swap_data[fdcount][count], sa.tmp_data[count], BUF_MAX); 
                      #ifdef THREAD_BUG
-                     printf("THREAD_BUG: sitar_scan(END block): Thread No = %ld\n", fdcount);
+                     printf("THREAD_BUG: sitar_scan(END block 3): Thread No = %ld\n", fdcount);
                      #endif
                      }
 
@@ -378,14 +370,14 @@ for(;;){
 
    #ifdef THREAD_BUG
    printf("THREAD_BUG: sitar_scan(): ループから抜けます。 fdcount<%ld>fdstat<%d>utime<%ld>\n",
-      fdcount, gd.td.fdstat[fdcount], u_time());
+      fdcount, gd.td.fdstat[fdcount], (long int)time(NULL));
    #endif
 
    sleep(gd.bf.bat2_int);
 
    #ifdef THREAD_BUG
    printf("THREAD_BUG: sitar_scan():  スリープから抜けました。 fdcount<%ld>fdstat<%d>utime<%ld>\n",
-      fdcount, gd.td.fdstat[fdcount], u_time());
+      fdcount, gd.td.fdstat[fdcount], (long int)time(NULL));
    #endif
 
    } // for(;;)
@@ -404,15 +396,16 @@ return 0;
 void * scan_block(int count)
 {
 char * tmp;
-int co, stat, errcount, mucount, mutexid, middleid, interval, wtime_1, wtime_2, wtime_3, wtime_4, instat;
+// int co, stat, errcount, mucount, mutexid, middleid, interval, wtime_1, wtime_2, wtime_3, wtime_4, instat;
+int co, stat, errcount, mucount, mutexid, middleid, interval, instat;
 char mid_stat;
 
 interval = (gd.bf.life_int + gd.bf.life_los + INT_PLUS);
 
-wtime_1 = 0;
-wtime_2 = 0;
-wtime_3 = 0;
-wtime_4 = 0;
+// wtime_1 = 0;
+// wtime_2 = 0;
+// wtime_3 = 0;
+// wtime_4 = 0;
 instat = 0;
 mucount = 0;
 mutexid = -1;
@@ -424,6 +417,7 @@ private_data_t *pd;
 
 
 // Pthread detachd このスレッドをデタッチします。
+// 元スレッドはこの関数の終わりを待ちません
 pthread_detach(pthread_self());
 
 if((pd = (private_data_t *)malloc(sizeof(private_data_t)))==NULL){exit(1);}
@@ -479,44 +473,57 @@ for(co = 0; sa.swap_data[pd->sb.fdno][co][0] != 0x00; co++){
             rm_crlf(pd->sb.ch_free3, strlen(pd->sb.ch_free3));
             rm_crlf(pd->sb.ch_free4, strlen(pd->sb.ch_free4));
 
-            pd->sb.port = strtol(pd->sb.ch_port, (char **)NULL, 10);
-            pd->sb.timeout = strtol(pd->sb.ch_timeout, (char **)NULL, 10);
 
-            if(pd->sb.timeout > TIME_OUT || pd->sb.timeout < 0){
-               if(pd->sb.timeout > TIME_OUT){
-                  pd->sb.timeout = 4;
-                  }
-               else{
-                  pd->sb.timeout = 0;
-                  }
-               fprintf(stderr,"scan_block(): default setup command time out %d\n", pd->sb.timeout);
+            // 一からむ目がSETでない場合はtimeoutを数字に変換
+            if(0 == self_memcmp(pd->sb.ch_tool, "SET")){
+               #ifdef MONITOR_BUG
+               fprintf(stderr,"scan_block(): SET sb.ch_tool = %s\n", pd->sb.ch_tool);
+               #endif 
                }
+            else{
+               #ifdef MONITOR_BUG
+               fprintf(stderr,"scan_block(): sb.ch_tool = %s\n", pd->sb.ch_tool);
+               #endif 
+
+               pd->sb.port = strtol(pd->sb.ch_port, (char **)NULL, 10);
+               pd->sb.timeout = strtol(pd->sb.ch_timeout, (char **)NULL, 10);
+
+               if(pd->sb.timeout > TIME_OUT || pd->sb.timeout < 0){
+                  if(pd->sb.timeout > TIME_OUT){
+                     pd->sb.timeout = 4;
+                     }
+                  else{
+                     pd->sb.timeout = 0;
+                     }
+                  }
+               }
+
 
             // SET は最初の行に限定される条件なので、最初に以下の監視条件を満たすことは無いです。
             pd->sb.ch_info = safe_memcpy(pd->sb.ch_info, "\n", BUF_MAX);
 
-            if(0 == memcmp(pd->sb.ch_tool, "PORT", 4)){
+            if(0 == self_memcmp(pd->sb.ch_tool, "PORT")){
                #ifdef MONITOR_BUG
                printf("MONITOR: %s: %s: %s: %s:\n",
                  pd->sb.ch_tool, pd->sb.ch_prot, pd->sb.ch_free1, pd->sb.ch_free4);
                #endif 
                scan_port(&pd->sb);
                }
-            else if(0 == memcmp(pd->sb.ch_tool, "COMAND", 6)){
+            else if(0 == self_memcmp(pd->sb.ch_tool, "COMAND")){
                #ifdef MONITOR_BUG
                printf("MONITOR: %s: %s: %s: %s:\n",
                  pd->sb.ch_tool, pd->sb.ch_prot, pd->sb.ch_free1, pd->sb.ch_free4);
                #endif 
                scan_comand(pd);
                }
-            else if(0 == memcmp(pd->sb.ch_tool, "SNMP", 4)){
+            else if(0 == self_memcmp(pd->sb.ch_tool, "SNMP")){
                #ifdef MONITOR_BUG
                printf("MONITOR: %s: %s: %s: %s:\n",
                  pd->sb.ch_tool, pd->sb.ch_prot, pd->sb.ch_free1, pd->sb.ch_free4);
                #endif 
                scan_snmp(&pd->sb);
                }
-            else if(0 == memcmp(pd->sb.ch_tool, "SET", 3)){
+            else if(0 == self_memcmp(pd->sb.ch_tool, "SET")){
                #ifdef MONITOR_BUG
                printf("MONITOR: %s: %s: %s: %s:\n",
                  pd->sb.ch_tool, pd->sb.ch_prot, pd->sb.ch_free1, pd->sb.ch_free4);
@@ -643,290 +650,126 @@ for(co = 0; sa.swap_data[pd->sb.fdno][co][0] != 0x00; co++){
                   // 排他処理に登録された場合の時間指定の確認
                   if(mutexid == 0){
 
+                     int ye_1, mo_1, da_1, ha_1, mi_1;
+                     int ye_2, mo_2, da_2, ha_2, mi_2;
+                     ye_1 = 0; mo_1 = 0; da_1 = 0; ha_1 = 0; mi_1 = 0;
+                     ye_2 = 0; mo_2 = 0; da_2 = 0; ha_2 = 0; mi_2 = 0;
+
                      // 時間指定（JUST)
                      if(0 == self_memcmp(pd->sb.ch_prot, "JUST")){
-                        pd->sb.ch_timeout_h = delim_get(pd->sb.ch_timeout, pd->sb.ch_timeout_h, ':', &instat, 0);
-                        if(instat >= 0){
-                           pd->sb.ch_timeout_m = delim_get(pd->sb.ch_timeout, pd->sb.ch_timeout_m, ':', &instat, 1); 
-                           if(instat >= 0){
-                              if((wtime_1 = strtol(pd->sb.ch_timeout_h, (char **)NULL, 10)) >= 0){
-                                 if((wtime_2 = strtol(pd->sb.ch_timeout_m, (char **)NULL, 10)) >= 0){
-                                    #ifdef MUTEX_BUG
-                                    printf("MUTEX: scan_block(): JUST時間単位で一回実行の設定がされました <%s>\n",
-                                      pd->sb.ch_prot);
-                                    #endif
-                                    // JUST 指定関数 hloop()
-                                    if(0 > hloop(wtime_1, wtime_2, gd.bf.bat2_int)){
-                                       #ifdef MUTEX_BUG
-                                       printf("MUTEX: scan_block(): JUSTで条件を満たしていないのでループを抜けます\n");
-                                       #endif 
-                                       goto forloopout;
-                                       }
-                                    else{
-                                       #ifdef MUTEX_BUG
-                                       printf("MUTEX: scan_block(): JUSTで条件を満たしたので監視を開始します。\n");
-                                       #endif 
-                                       }
-                                    wtime_2 = 0;
-                                    pd->sb.ch_timeout_m = safe_memcpy(pd->sb.ch_timeout_m, "\n", BUF_LEN);
-                                    }
-                                 else{
-                                    fprintf(stderr,"MUTEX: scan_block(): JUST時間単位で指定値の(分)変換が出来ませんでした <%s>\n",
-                                      pd->sb.ch_timeout_m);
-                                    wtime_2 = 0;
-                                    pd->sb.ch_timeout_m = safe_memcpy(pd->sb.ch_timeout_m, "\n", BUF_LEN);
-                                    goto forloopout;
-                                    }
-                                 wtime_1 = 0;
-                                 pd->sb.ch_timeout_h = safe_memcpy(pd->sb.ch_timeout_h, "\n", BUF_LEN);
-                                 }
-                              else{
-                                 fprintf(stderr,"MUTEX: scan_block(): JUST時間単位で指定値の(時)変換が出来ませんでした <%s>\n",
-                                   pd->sb.ch_timeout_h);
-                                 wtime_1 = 0;
-                                 pd->sb.ch_timeout_h = safe_memcpy(pd->sb.ch_timeout_h, "\n", BUF_LEN);
-                                 goto forloopout;
-                                 }
-                              }  // instat 2
-                           else{
-                              fprintf(stderr,"MUTEX: scan_block(2): JUST時間単位で指定値のフォーマットに問題があります <%s>\n",
-                                 pd->sb.ch_timeout);
-                              goto forloopout;
-                              }
-                           }  // instat 1
-                        else{
-                           fprintf(stderr,"MUTEX: scan_block(1): JUST時間単位で指定値のフォーマットに問題があります <%s>\n",
-                              pd->sb.ch_timeout);
+                        if(time_format(pd->sb.ch_timeout, &ye_1, &mo_1, &da_1, &ha_1, &mi_1) < 0){
+                           fprintf(stderr,"MUTEX: scan_block(): JUST時間単位で指定値の変換が正しく出来ませんでした <%s>\n",
+                             pd->sb.ch_timeout);
+                           ye_1 = 2008; mo_1 = 1; da_1 = 1; ha_1 = 0; mi_1 = 0;
                            goto forloopout;
                            }
-                        }
-
-
-
-
-
-
-
-                     // 時間指定RES(以外) スーパーネスト！w そのうちきれいになおしまふ
-                     else if(0 == self_memcmp(pd->sb.ch_prot, "RES")){
-                        // 文字列を分解します
-                        pd->sb.ch_port_h = delim_get(pd->sb.ch_port, pd->sb.ch_port_h, ':', &instat, 0);
-                        if(instat >= 0){
-                           pd->sb.ch_port_m = delim_get(pd->sb.ch_port, pd->sb.ch_port_m, ':', &instat, 1); 
-                           if(instat >= 0){
-                              pd->sb.ch_timeout_h = delim_get(pd->sb.ch_timeout, pd->sb.ch_timeout_h, ':', &instat, 0);
-                              if(instat >= 0){
-                                 pd->sb.ch_timeout_m = delim_get(pd->sb.ch_timeout, pd->sb.ch_timeout_m, ':', &instat, 1); 
-                                 if(instat >= 0){
-                                    // 数字にします
-                                    if((wtime_1 = strtol(pd->sb.ch_port_h, (char **)NULL, 10)) >= 0){
-                                       if((wtime_2 = strtol(pd->sb.ch_port_m, (char **)NULL, 10)) >= 0){
-                                          if((wtime_3 = strtol(pd->sb.ch_timeout_h, (char **)NULL, 10)) >= 0){
-                                             if((wtime_4 = strtol(pd->sb.ch_timeout_m, (char **)NULL, 10)) >= 0){
- 
-                                                #ifdef MUTEX_BUG
-                                                printf("MUTEX: scan_block(): RES時間単位で指定時間内実行の設定がされました<%s>\n",
-                                                  pd->sb.ch_prot);
-                                                #endif 
-                                                // RES 指定関数 floop()
-                                                if(0 <= floop(wtime_1, wtime_2, wtime_3, wtime_4)){
-                                                   #ifdef MUTEX_BUG
-                                                   printf("MUTEX: scan_block(): RESで条件を満たしたので監視を行いません <%d>から<%d>\n",
-                                                     wtime_1, wtime_2);
-                                                   #endif
-                                                   goto forloopout;
-                                                   }
-                                                else{
-                                                   #ifdef MUTEX_BUG
-                                                   printf("MUTEX: scan_block(): RESで条件を満たしていないので監視を開始します。\n");
-                                                   #endif 
-                                                   }
-                                                wtime_1 = 0;
-                                                wtime_2 = 0;
-                                                wtime_3 = 0;
-                                                wtime_4 = 0;
-                                                }
-                                             else{
-                                                fprintf(stderr,"MUTEX: scan_block(): RES時間単位で開始(分)変換が出来ませんでした <%s>\n",
-                                                 pd->sb.ch_timeout_m);
-                                                wtime_4 = 0;
-                                                pd->sb.ch_timeout_m = safe_memcpy(pd->sb.ch_timeout_m, "\n", BUF_LEN);
-                                                goto forloopout;
-                                                }
-                                             wtime_3 = 0;
-                                             pd->sb.ch_timeout_h = safe_memcpy(pd->sb.ch_timeout_h, "\n", BUF_LEN);
-                                             }
-                                          else{
-                                             fprintf(stderr,"MUTEX: scan_block(): RES時間単位で開始(時)変換が出来ませんでした <%s>\n",
-                                               pd->sb.ch_timeout_h);
-                                             wtime_3 = 0;
-                                             pd->sb.ch_timeout_h = safe_memcpy(pd->sb.ch_timeout_h, "\n", BUF_LEN);
-                                             goto forloopout;
-                                             }
-                                          }
-                                       else{
-                                          fprintf(stderr,"MUTEX: scan_block(): RES(停止分)の数字変換が出来ませんでした <%s>\n",
-                                            pd->sb.ch_port_m);
-                                          wtime_2 = 0;
-                                          pd->sb.ch_port_m = safe_memcpy(pd->sb.ch_port_m, "\n", BUF_LEN);
-                                          goto forloopout;
-                                          }
-                                       wtime_1 = 0;
-                                       pd->sb.ch_port_h = safe_memcpy(pd->sb.ch_port_h, "\n", BUF_LEN);
-                                       }
-                                    else{
-                                       fprintf(stderr,"MUTEX: scan_block(): RES(停止時)の数字変換が出来ませんでした <%s>\n",
-                                         pd->sb.ch_port_h);
-                                       wtime_1 = 0;
-                                       pd->sb.ch_port_h = safe_memcpy(pd->sb.ch_port_h, "\n", BUF_LEN);
-                                       goto forloopout;
-                                       }
-                                    }  // instat 4 
-                                 else{
-                                    fprintf(stderr,"MUTEX: scan_block(2): RES(分単位)で指定値(開始)のフォーマットに問題があります <%s>\n",
-                                       pd->sb.ch_timeout);
-                                    goto forloopout;
-                                    }
-                                 }  // instat 3
-                              else{
-                                 fprintf(stderr,"MUTEX: scan_block(1): RES(時間単位)で指定値(開始)のフォーマットに問題があります <%s>\n",
-                                    pd->sb.ch_timeout);
-                                 goto forloopout;
-                                 }
-                              }  // instat 2
-                           else{
-                              fprintf(stderr,"MUTEX: scan_block(2): RES(分単位)で指定値(停止)のフォーマットに問題があります <%s>\n",
-                                 pd->sb.ch_port);
+                        else{
+                           #ifdef MUTEX_BUG
+                           printf("MUTEX: scan_block(): JUST時間単位で一回実行の設定がされました <%s>\n",
+                             pd->sb.ch_prot);
+                           #endif
+                           // JUST 指定関数 hloop()
+                           if(0 > hloop(ye_1, mo_1, da_1, ha_1, mi_1, gd.bf.bat2_int)){
+                              #ifdef MUTEX_BUG
+                              printf("MUTEX: scan_block(): JUSTで条件を満たしていないのでループを抜けます\n");
+                              #endif 
                               goto forloopout;
                               }
-                           }  // instat 1
-                        else{
-                           fprintf(stderr,"MUTEX: scan_block(1): RES(時間単位)で指定値(停止)のフォーマットに問題があります <%s>\n",
-                              pd->sb.ch_port);
+                           else{
+                              #ifdef MUTEX_BUG
+                              printf("MUTEX: scan_block(): JUSTで条件を満たしたので監視を開始します。\n");
+                              #endif 
+                              }
+                           ye_1 = 0; mo_1 = 0; da_1 = 0; ha_1 = 0; mi_1 = 0;
+                           }
+                        }   // JUST
+
+
+
+                     // 時間指定RES(以外)
+                     else if(0 == self_memcmp(pd->sb.ch_prot, "RES")){
+                        if(time_format(pd->sb.ch_port, &ye_1, &mo_1, &da_1, &ha_1, &mi_1) < 0){
+                           fprintf(stderr,"MUTEX: scan_block(): RES STOP時間指定値の変換が正しく出来ませんでした <%s>\n",
+                             pd->sb.ch_port);
+                           ye_1 = 0; mo_1 = 0; da_1 = 0; ha_1 = 0; mi_1 = 0;
                            goto forloopout;
                            }
+                        else{
+                           if(time_format(pd->sb.ch_timeout, &ye_2, &mo_2, &da_2, &ha_2, &mi_2) < 0){
+                              fprintf(stderr,"MUTEX: scan_block(): RES START時間指定値の変換が正しく出来ませんでした <%s>\n",
+                                pd->sb.ch_timeout);
+                              ye_2 = 0; mo_2 = 0; da_2 = 0; ha_2 = 0; mi_2 = 0;
+                              goto forloopout;
+                              }
+                           else{
+                              #ifdef MUTEX_BUG
+                              printf("MUTEX: scan_block(): RES 時間指定実行停止の設定がされました<%s>\n",
+                                pd->sb.ch_prot);
+                              #endif 
+                              // RES 指定関数 floop()
+                              if(0 <= floop(ye_1, mo_1, da_1, ha_1, mi_1,
+                                            ye_2, mo_2, da_2, ha_2, mi_2)){
+                                 #ifdef MUTEX_BUG
+                                 printf("MUTEX: scan_block(): RESで条件を満たしたので監視を行いません <%d>から<%d>\n",
+                                   ha_1, mi_1);
+                                 #endif
+                                 goto forloopout;
+                                 }
+                              else{
+                                 #ifdef MUTEX_BUG
+                                 printf("MUTEX: scan_block(): RESで条件を満たしていないので監視を再開します。\n");
+                                 #endif 
+                                 }
+                              ye_1 = 0; mo_1 = 0; da_1 = 0; ha_1 = 0; mi_1 = 0;
+                              ye_2 = 0; mo_2 = 0; da_2 = 0; ha_2 = 0; mi_2 = 0;
+                              }
+                           }
                         }   // RES
 
 
-
-
-
-
-
-
-
-
-
-
-
-
-
                      // 時間指定FOR(条件を満たしている間) スーパーネスト！w そのうちきれいになおしまふ
                      else if(0 == self_memcmp(pd->sb.ch_prot, "FOR")){
-                        // 文字列を分解します
-                        pd->sb.ch_port_h = delim_get(pd->sb.ch_port, pd->sb.ch_port_h, ':', &instat, 0);
-                        if(instat >= 0){
-                           pd->sb.ch_port_m = delim_get(pd->sb.ch_port, pd->sb.ch_port_m, ':', &instat, 1); 
-                           if(instat >= 0){
-                              pd->sb.ch_timeout_h = delim_get(pd->sb.ch_timeout, pd->sb.ch_timeout_h, ':', &instat, 0);
-                              if(instat >= 0){
-                                 pd->sb.ch_timeout_m = delim_get(pd->sb.ch_timeout, pd->sb.ch_timeout_m, ':', &instat, 1); 
-                                 if(instat >= 0){
-                                    // 数字にします
-                                    if((wtime_1 = strtol(pd->sb.ch_port_h, (char **)NULL, 10)) >= 0){
-                                       if((wtime_2 = strtol(pd->sb.ch_port_m, (char **)NULL, 10)) >= 0){
-                                          if((wtime_3 = strtol(pd->sb.ch_timeout_h, (char **)NULL, 10)) >= 0){
-                                             if((wtime_4 = strtol(pd->sb.ch_timeout_m, (char **)NULL, 10)) >= 0){
- 
-                                                #ifdef MUTEX_BUG
-                                                printf("MUTEX: scan_block(): FOR時間単位で指定時間内実行の設定がされました<%s>\n",
-                                                  pd->sb.ch_prot);
-                                                #endif 
-                                                // FOR 指定関数 floop()
-                                                if(0 > floop(wtime_1, wtime_2, wtime_3, wtime_4)){
-                                                   #ifdef MUTEX_BUG
-                                                   printf("MUTEX: scan_block(): FORで条件を満たしていないのでループを抜けます <%d>から<%d>\n",
-                                                     wtime_1, wtime_2);
-                                                   #endif
-                                                   goto forloopout;
-                                                   }
-                                                else{
-                                                   #ifdef MUTEX_BUG
-                                                   printf("MUTEX: scan_block(): FORで条件を満たしたので監視を開始します。砿n");
-                                                   #endif 
-                                                   }
-                                                wtime_1 = 0;
-                                                wtime_2 = 0;
-                                                wtime_3 = 0;
-                                                wtime_4 = 0;
-                                                }
-                                             else{
-                                                fprintf(stderr,"MUTEX: scan_block(): FOR時間単位で終了(停止分)変換が出来ませんでした <%s>\n",
-                                                 pd->sb.ch_timeout_m);
-                                                wtime_4 = 0;
-                                                pd->sb.ch_timeout_m = safe_memcpy(pd->sb.ch_timeout_m, "\n", BUF_LEN);
-                                                goto forloopout;
-                                                }
-                                             wtime_3 = 0;
-                                             pd->sb.ch_timeout_h = safe_memcpy(pd->sb.ch_timeout_h, "\n", BUF_LEN);
-                                             }
-                                          else{
-                                             fprintf(stderr,"MUTEX: scan_block(): FOR時間単位で終了(停止時)変換が出来ませんでした <%s>\n",
-                                               pd->sb.ch_timeout_h);
-                                             wtime_3 = 0;
-                                             pd->sb.ch_timeout_h = safe_memcpy(pd->sb.ch_timeout_h, "\n", BUF_LEN);
-                                             goto forloopout;
-                                             }
-                                          }
-                                       else{
-                                          fprintf(stderr,"MUTEX: scan_block(): FOR(開始分)の数字変換が出来ませんでした <%s>\n",
-                                            pd->sb.ch_port_m);
-                                          wtime_2 = 0;
-                                          pd->sb.ch_port_m = safe_memcpy(pd->sb.ch_port_m, "\n", BUF_LEN);
-                                          goto forloopout;
-                                          }
-                                       wtime_1 = 0;
-                                       pd->sb.ch_port_h = safe_memcpy(pd->sb.ch_port_h, "\n", BUF_LEN);
-                                       }
-                                    else{
-                                       fprintf(stderr,"MUTEX: scan_block(): FOR(開始時)の数字変換が出来ませんでした <%s>\n",
-                                         pd->sb.ch_port_h);
-                                       wtime_1 = 0;
-                                       pd->sb.ch_port_h = safe_memcpy(pd->sb.ch_port_h, "\n", BUF_LEN);
-                                       goto forloopout;
-                                       }
-                                    }  // instat 4 
-                                 else{
-                                    fprintf(stderr,"MUTEX: scan_block(2): FOR(分単位)で指定値(停止)のフォーマットに問題があります <%s>\n",
-                                       pd->sb.ch_timeout);
-                                    goto forloopout;
-                                    }
-                                 }  // instat 3
-                              else{
-                                 fprintf(stderr,"MUTEX: scan_block(1): FOR(時間単位)で指定値(停止)のフォーマットに問題があります <%s>\n",
-                                    pd->sb.ch_timeout);
-                                 goto forloopout;
-                                 }
-                              }  // instat 2
-                           else{
-                              fprintf(stderr,"MUTEX: scan_block(2): FOR(分単位)で指定値(開始)のフォーマットに問題があります <%s>\n",
-                                 pd->sb.ch_port);
+                        if(time_format(pd->sb.ch_port, &ye_1, &mo_1, &da_1, &ha_1, &mi_1) < 0){
+                           fprintf(stderr,"MUTEX: scan_block(): FOR START時間指定値の変換が正しく出来ませんでした <%s>\n",
+                             pd->sb.ch_port);
+                           ye_1 = 0; mo_1 = 0; da_1 = 0; ha_1 = 0; mi_1 = 0;
+                           goto forloopout;
+                           }
+                        else{
+                           if(time_format(pd->sb.ch_timeout, &ye_2, &mo_2, &da_2, &ha_2, &mi_2) < 0){
+                              fprintf(stderr,"MUTEX: scan_block(): FOR STOP時間指定値の変換が正しく出来ませんでした <%s>\n",
+                                pd->sb.ch_timeout);
+                              ye_2 = 0; mo_2 = 0; da_2 = 0; ha_2 = 0; mi_2 = 0;
                               goto forloopout;
                               }
-                           }  // instat 1
-                        else{
-                           fprintf(stderr,"MUTEX: scan_block(1): FOR(時間単位)で指定値(開始)のフォーマットに問題があります <%s>\n",
-                              pd->sb.ch_port);
-                           goto forloopout;
+                           else{
+                              #ifdef MUTEX_BUG
+                              printf("MUTEX: scan_block(): FOR時間単位で指定時間内実行の設定がされました<%s>\n",
+                                pd->sb.ch_prot);
+                              #endif 
+                              // FOR 指定関数 floop()
+                              if(0 > floop(ye_1, mo_1, da_1, ha_1, mi_1,
+                                           ye_2, mo_2, da_2, ha_2, mi_2)){
+                                 #ifdef MUTEX_BUG
+                                 printf("MUTEX: scan_block(): FORで条件を満たしていないのでループを抜けます <%d>から<%d>\n",
+                                   ha_1, mi_1);
+                                 #endif
+                                 goto forloopout;
+                                 }
+                              else{
+                                 #ifdef MUTEX_BUG
+                                 printf("MUTEX: scan_block(): FORで条件を満たしたので監視を開始します。\n");
+                                 #endif 
+                                 }
+                              ye_1 = 0; mo_1 = 0; da_1 = 0; ha_1 = 0; mi_1 = 0;
+                              ye_2 = 0; mo_2 = 0; da_2 = 0; ha_2 = 0; mi_2 = 0;
+                              }
                            }
                         }   // FOR
 
 
 
-
-
-
-                     // 時間指定 (FOR JUST) 以外の場合 
+                     // 時間指定 (FOR RES JUST) 以外の場合 
                      else{
                         #ifdef MUTEX_BUG
                         printf("MUTEX: scan_block(): 時間単位の設定は入っていません\n");
@@ -979,9 +822,10 @@ for(co = 0; sa.swap_data[pd->sb.fdno][co][0] != 0x00; co++){
 
                   // SET 行の作成
                   pd->sb.swap_2 = safe_sprintf(pd->sb.swap_2, BUF_MAX,
-                     "%s,%ld,%ld,%ld,%ld,%ld,%ld,%ld,%s,%s,%s,%s,%d,%d,%s,%s,%s,%s,%s,%s,%s;",
+//                   "%s,%ld,%ld,%ld,%ld,%ld,%ld,%ld,%s,%s,%s,%s,%d,%d,%s,%s,%s,%s,%s,%s,%s;",
+                     "%s,%ld,%ld,%ld,%ld,%ld,%ld,%ld,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s;",
                      pd->sb.ch_tool,
-                     u_time(),
+                     (long int)time(NULL),
                      ctime_getr('y'),
                      ctime_getr('m'),
                      ctime_getr('d'),
@@ -992,8 +836,10 @@ for(co = 0; sa.swap_data[pd->sb.fdno][co][0] != 0x00; co++){
                      "NOT",
                      pd->sb.ch_plai,
                      pd->sb.ch_prot,
-                     wtime_1,
-                     wtime_2,
+                     pd->sb.ch_port,
+                     pd->sb.ch_timeout,
+//                   wtime_1,
+//                   wtime_2,
                      "NOT",
                      pd->sb.ch_info,
                      "NOT",
@@ -1028,7 +874,7 @@ for(co = 0; sa.swap_data[pd->sb.fdno][co][0] != 0x00; co++){
                pd->sb.swap_2 = safe_sprintf(pd->sb.swap_2, BUF_MAX,
                   "%s,%ld,%ld,%ld,%ld,%ld,%ld,%ld,%s,%s,%s,%s,%d,%d,%s,%s,%s,%s,%s,%s,%s;",
                   pd->sb.ch_tool,
-                  u_time(),
+                  (long int)time(NULL),
                   ctime_getr('y'),
                   ctime_getr('m'),
                   ctime_getr('d'),
@@ -1086,7 +932,7 @@ if(sa.buf_err[pd->sb.fdno] == 1){
    pd->sb.swap_2 = safe_sprintf(pd->sb.swap_2, BUF_MAX,
         "%s,%ld,%ld,%ld,%ld,%ld,%ld,%ld,%s,%s,%s,%s,%d,%d,%s,%s,%s,%s,%s,%s,%s;",
         "INFO",
-        u_time(),
+        (long int)time(NULL),
         ctime_getr('y'),
         ctime_getr('m'),
         ctime_getr('d'),
@@ -1275,7 +1121,7 @@ return data;
 
 
 
-// コマンド監視用関数
+/* コマンド監視用関数
 int scan_comand(private_data_t *pd)
 {
 int ret = -1;
@@ -1289,36 +1135,79 @@ printf("MYPEXEC: scan_comand() %s\n", pd->sb.ch_com);
 printf("MYPEXEC: scan_comand() sb.ch_plai = %s\n", pd->sb.ch_plai);
 #endif
 
-/* テストモード */
-if(0 == memcmp(pd->sb.ch_plai, "4", 1)){
+// テストモード  priority 4
+if(0==self_memcmp(pd->sb.ch_plai, "4")){
    #ifdef MYPEXEC_DEBUG
    printf("MYPEXEC: scna_comand() コマンド  テストモード\n");
    #endif
    pd->sb.ch_info = execom(pd->sb.ch_com, pd->sb.ch_info, pd->sb.timeout, 1);
-   if(1 < strlen(pd->sb.ch_info)){
+   if(1 < strlen(pd->sb.ch_info)){    // 何らかの出力のある場合の処理
       #ifdef MYPEXEC_DEBUG
       printf("MYPEXEC: scan_comand() %s 標準出力＆エラー出力 (テストモード) \n", pd->sb.ch_info);
       #endif
       }
-   if(1 >= strlen(pd->sb.ch_info)){
+   if(1 >= strlen(pd->sb.ch_info)){    // 何らかの出力の無い場合の処理
       #ifdef MYPEXEC_DEBUG
       printf("MYPEXEC: scan_comand() %s は  正常に終了しました(テストモード) \n", pd->sb.ch_com);
       #endif
       pd->sb.ch_info = safe_memcpy(pd->sb.ch_info, COM_3, BUF_MAX );
       } 
    }
-/* 通常モード */
+
+// テストモード  priority 11,12,13 
+else if(0==self_memcmp(pd->sb.ch_plai, "11")
+     || 0==self_memcmp(pd->sb.ch_plai, "12") || 0==self_memcmp(pd->sb.ch_plai, "13")){
+   #ifdef MYPEXEC_DEBUG
+   printf("MYPEXEC: scna_comand() コマンド  テストモード\n");
+   #endif
+   pd->sb.ch_info = execom(pd->sb.ch_com, pd->sb.ch_info, pd->sb.timeout, 1);
+   if(1 < strlen(pd->sb.ch_info)){    // 何らかの出力のある場合の処理
+      #ifdef MYPEXEC_DEBUG
+      printf("MYPEXEC: scan_comand() %s 標準出力＆エラー出力 (テストモード) \n", pd->sb.ch_info);
+      #endif
+      if(0 == memcmp(pd->sb.ch_info, "NG:", 3)){  // 返却文字列の先頭に'NG:'がある場合の処理（エラー）
+         if(0==self_memcmp(pd->sb.ch_plai, "11")){
+            pd->sb.ch_plai = safe_memcpy(pd->sb.ch_plai, "1", BUF_MAX);
+            }
+         else if(0==self_memcmp(pd->sb.ch_plai, "12")){
+            pd->sb.ch_plai = safe_memcpy(pd->sb.ch_plai, "2", BUF_MAX);
+            }
+         else if(0==self_memcmp(pd->sb.ch_plai, "13")){
+            pd->sb.ch_plai = safe_memcpy(pd->sb.ch_plai, "3", BUF_MAX);
+            }
+         else{
+            }
+         #ifdef MYPEXEC_DEBUG
+         printf("MYPEXEC: scan_comand() %s priority が11,12,13で先頭にNG、prioriytの変更 %d\n",
+           pd->sb.ch_info, pd->sb.ch_plai);
+         #endif
+         }
+      else{                                       // 返却文字列の先頭に'NG:'がない場合の処理（エラー）
+         #ifdef MYPEXEC_DEBUG
+         printf("MYPEXEC: scan_comand() %s priority が11,12,13で先頭にNGが含まれない\n", pd->sb.ch_info);
+         #endif
+         }
+      }
+   if(1 >= strlen(pd->sb.ch_info)){    // 何らかの出力の無い場合の処理
+      #ifdef MYPEXEC_DEBUG
+      printf("MYPEXEC: scan_comand() %s は  正常に終了しました(テストモード) \n", pd->sb.ch_com);
+      #endif
+      pd->sb.ch_info = safe_memcpy(pd->sb.ch_info, COM_3, BUF_MAX );
+      } 
+   }
+
+// 通常モード 1,2,3 
 else{
    #ifdef MYPEXEC_DEBUG
    printf("MYPEXEC: scan_comand() コマンド  通常モード\n");
    #endif
    pd->sb.ch_info = execom(pd->sb.ch_com, pd->sb.ch_info, pd->sb.timeout, 1);
-   if(1 < strlen(pd->sb.ch_info)){
+   if(1 < strlen(pd->sb.ch_info)){    // 何らかの出力のある場合の処理
       #ifdef MYPEXEC_DEBUG
       printf("MYPEXEC: scan_comand() %s 標準＆エラー出力 (通常モード) \n", pd->sb.ch_info);
       #endif
       }
-   if(1 >= strlen(pd->sb.ch_info)){
+   if(1 >= strlen(pd->sb.ch_info)){   // 何らかの出力の無い場合の処理
       #ifdef MYPEXEC_DEBUG
       printf("MYPEXEC: scan_comand() %s は  正常に終了しました(通常モード) \n", pd->sb.ch_com);
       #endif
@@ -1350,11 +1239,11 @@ else{
 
 return ret;
 }
+*/
 
 
 
-
-// キャラの置き換え関数
+/* キャラの置き換え関数
 int swap_char(char * chdata)
 {
 swap_mem(chdata, ';', ' ', strlen(chdata));
@@ -1365,6 +1254,8 @@ swap_mem(chdata, '<', ' ', strlen(chdata));
 return 0;
 }
 
+*/
+
 
 
 
