@@ -7,7 +7,11 @@
 
 // #include"config.h"
 
-  #define CL_VAR "sitar-1.1.13"
+  #ifndef _VERSION_H_
+     #include "version.h"
+  #endif
+
+  #define CL_VAR "sitar-"VERSION
   #define CONF_PATH "/etc/sitar.conf"
 
   #define BUF_LEN  256 
