@@ -15,7 +15,7 @@
 
 
 #include"zither.h"
-#include"almemsys.h"
+#include<almemsys/almemsys.h>
 
 /* int stat_check(char [], char *, int, int *); */
 
