@@ -8,10 +8,11 @@
 #include<string.h>
 #include<stdlib.h>
 #include<arpa/inet.h>
+#include<time.h>
 #include<pthread.h>
 
 #include"zither.h"
-#include"almemsys.h"
+#include<almemsys/almemsys.h>
 
 /*
 int life_check(private_data_t *);
@@ -26,7 +27,7 @@ long int intime = 0;
 int count = 0;
 
 lostime = 0;
-intime = u_time();
+intime = (long int)time(NULL);
 
 for(count = (LIFE_HI - 1); 1 <= count; count = count-1){
    pd->life.in_life[count] = pd->life.in_life[count - 1];
