@@ -1611,7 +1611,7 @@ pthread_mutex_unlock(&pg_mutex);
 
 
 // メールのプライオリティー設定
-if(1 == strlen(plai)){
+if(0 == ch_int2(plai)){
    pri = strtol(plai, (char **)NULL, 10);
 
    if(pri == 1){
@@ -1627,7 +1627,7 @@ if(1 == strlen(plai)){
    }
 else{
    pri = 3;
-   fprintf(stderr,"mail_form(): plai size err %s\n", plai);
+   fprintf(stderr,"mail_form(): プライオリティーが数字でないので3にします %s\n", plai);
    }
 
 
